/*  ietfmib.h - data to monitor SNMP UPS (RFC 1628 compliant) with NUT
 *
 *  Copyright (C) 2002-2003 
 *  			Dmitry Frolov <frolov@riss-telecom.ru>
 *  			Arnaud Quette <arnaud.quette@free.fr>
 *
 *  data structure and processing principles are inspired by:
 *            Hans Ekkehard Plesser <hans.plesser@itf.nlh.no>
 *
 *  Sponsored by MGE UPS SYSTEMS <http://www.mgeups.com>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#define IETF_MIB_VERSION	"1.0"

/* SNMP OIDs set */
#define IETF_OID_UPS_MIB      ".1.3.6.1.2.1.33"
#define IETF_OID_MFR_NAME     ".1.3.6.1.2.1.33.1.1.1"
#define IETF_OID_MODEL_NAME   ".1.3.6.1.2.1.33.1.1.2"
#define IETF_OID_FIRMREV      ".1.3.6.1.2.1.33.1.1.4"
#define IETF_OID_BATT_STATUS  ".1.3.6.1.2.1.33.1.2.1"     /* INFO_STATUS (2) */
#define IETF_OID_BATT_RUNTIME ".1.3.6.1.2.1.33.1.2.3"
#define IETF_OID_BATT_CHARGE  ".1.3.6.1.2.1.33.1.2.4"
#define IETF_OID_BATT_VOLTAGE ".1.3.6.1.2.1.33.1.2.5"
#define IETF_OID_POWER_STATUS ".1.3.6.1.2.1.33.1.4.1"     /* INFO_STATUS (1) */
#define IETF_OID_OUT_VOLTAGE  ".1.3.6.1.2.1.33.1.9.3"     /* INFO_UTILITY ? */
#define IETF_OID_UTIL_VOLTAGE ".1.3.6.1.2.1.33.1.4.4.1.2" /* INFO_UTILITY ? */
#define IETF_OID_LOAD_LEVEL   ".1.3.6.1.2.1.33.1.4.4.1.5" /* INFO_LOADPCT */
#define IETF_OID_OUTPUT_TAB   ".1.3.6.1.2.1.33.1.4.4"

/* Defines for IETF_OID_POWER_STATUS (1) */
#define IETF_PWR_OTHER 		1	/* other -> INFO_STATUS/? */
#define IETF_PWR_NONE 		2	/* none -> INFO_STATUS/OFF */
#define IETF_PWR_NORMAL 	3	/* normal -> INFO_STATUS/OL */
#define IETF_PWR_BYPASS 	4	/* bypass -> INFO_STATUS/? */
#define IETF_PWR_BATTERY 	5	/* battery -> INFO_STATUS/OB */
#define IETF_PWR_BOOSTER 	6	/* booster -> INFO_STATUS/BOOST */
#define IETF_PWR_REDUCER 	7	/* reducer -> INFO_STATUS/TRIM */

info_lkp_t ietf_pwr_info[] = {
/*	{ IETF_PWR_OTHER, "" }, */
	{ IETF_PWR_NONE, "OFF" },
	{ IETF_PWR_NORMAL, "OL" },
/*	{ IETF_PWR_BYPASS, "" }, */
	{ IETF_PWR_BATTERY, "OB" },
	{ IETF_PWR_BOOSTER, "BOOST" },
	{ IETF_PWR_REDUCER, "TRIM" },
	{ 0, "\0" }
} ;

/* Defines for IETF_OID_BATT_STATUS (2) */
#define IETF_BATT_UNKNOWN  1 /* unknown -> INFO_STATUS/? */
#define IETF_BATT_NORMAL   2 /* batteryNormal -> INFO_STATUS/? */
#define IETF_BATT_LOW      3 /* batteryLow -> INFO_STATUS/LB */
#define IETF_BATT_DEPLETED 4 /* batteryDepleted -> INFO_STATUS/? */

info_lkp_t ietf_batt_info[] = {
/*	{ IETF_BATT_UNKNOWN, "" }, */
/*	{ IETF_BATT_NORMAL, "" }, */
	{ IETF_BATT_LOW, "LB" },
/*	{ IETF_BATT_DEPLETED, "" }, */
	{ 0, "\0" }
} ;

#define IETF_OID_SD_AFTER_DELAY		".1.3.6.1.2.1.33.1.8.2"
#define IETF_OFF_DO					0

/* Missing data
   CAL   - UPS is performing calibration
   OVER  - UPS is overloaded
   RB    - UPS battery needs to be replaced
   FSD   - UPS is in forced shutdown state (slaves take note)
*/

/* Snmp2NUT lookup table */

snmp_info_t ietf_mib[] = {
	
	/* info elements. */
	{ INFO_MFR, FLAG_STRING, SU_INFOSIZE, IETF_OID_MFR_NAME, "Generic",
		SU_FLAG_STATIC | SU_FLAG_OK, NULL },
	{ INFO_MODEL, FLAG_STRING, SU_INFOSIZE, IETF_OID_MODEL_NAME,
		"Generic SNMP UPS", SU_FLAG_STATIC | SU_FLAG_OK, NULL },
	{ INFO_FIRMREV, FLAG_STRING, SU_INFOSIZE, IETF_OID_FIRMREV, "",
		SU_FLAG_STATIC | SU_FLAG_OK, NULL },
	{ INFO_STATUS, FLAG_STRING, SU_INFOSIZE, IETF_OID_POWER_STATUS, "OFF",
		SU_FLAG_OK | SU_STATUS_PWR, &ietf_pwr_info[0] },
	{ INFO_STATUS, FLAG_STRING, SU_INFOSIZE, IETF_OID_BATT_STATUS, "",
		SU_FLAG_OK | SU_STATUS_BATT, &ietf_batt_info[0] },
	{ INFO_BATTPCT, 0,1, IETF_OID_BATT_CHARGE, "", SU_FLAG_OK, NULL },
	{ INFO_RUNTIME, 0, 60, IETF_OID_BATT_RUNTIME, "", SU_TYPE_TIME | SU_FLAG_OK, NULL },
	{ INFO_BATTVOLT, 0, 1, IETF_OID_BATT_VOLTAGE, "", SU_FLAG_OK, NULL },
	{ INFO_OUTVOLT, 0, 1, IETF_OID_OUT_VOLTAGE, "", SU_FLAG_OK, NULL },
	{ INFO_LOADPCT, 0, 1, IETF_OID_LOAD_LEVEL, "", SU_FLAG_OK, NULL },
	
	/* instant commands. */
	{ CMD_OFF, 0, IETF_OFF_DO, IETF_OID_SD_AFTER_DELAY, "", SU_FLAG_OK, NULL },
/*	{ CMD_SHUTDOWN, 0, IETF_OFF_GRACEFUL, IETF_OID_OFF, "", SU_FLAG_OK, NULL }, */
	
	/* end of structure. */
	{ INFO_UNUSED, 0, 0, NULL, NULL, 0, NULL }
};
